@@ -135,7 +135,7 @@ class ShapleyLorenzShare:
             specifies, whether to plot a seperate graph for the
             class tuple, in case of multiple classes
         '''
-        lz_sorted = lz_shares[np.argsort(lz_shares[:,1])]
+        lz_sorted = LZ[np.argsort(LZ[:,1])]
         if tuple == False:
             plt.bar(lz_sorted[:,0], lz_sorted[:,1], color = (0.0,0.36,0.8,0.8))
             plt.title('Shapley Lorenz Zonoid Values', fontsize = '15')
